*** Settings ***
Documentation     A resource file with reusable keywords.

Resource        variables.robot
Library         Selenium2Library
Library         Collections
Library         String

*** Keywords ***

Open Browser for Device
    ${chrome_options}=    Set Chrome Options
    Create Webdriver    ${BROWSER}    chrome_options=${chrome_options}
    Set Window Size    1280    1104
    Set Selenium Implicit Wait    5
    Go to    ${url}
    Device Should Be Open


Set Chrome Options
    [Documentation]    Set Chrome options for headless mode
    ${options}=    Evaluate    sys.modules['selenium.webdriver'].ChromeOptions()    sys, selenium.webdriver
    : FOR    ${option}    IN    @{chrome_arguments}
    \    Call Method    ${options}    add_argument    ${option}
    [Return]    ${options}


Device Should Be Open
    Location Should Contain    http://${SERVER}/


Go to Imaging
    Click Element    //div[@id="navbtn_clone"]


Go to Hash
    Click Element    //div[@id="navbtn_hash"]


Create tasks
    Click Element    //div[@id="clone_add_btn"]
    Click Element    //div[@id="clone_add_btn"]
    Click Element    //div[@id="clone_add_btn"]
    Click Element    //div[@id="clone_add_btn"]


Go to Task
    [Arguments]  ${ttask}=4

    Click Element    //div[@id="clone_tab_${ttask}"]
    Sleep    1s


Press OK
    [Arguments]  ${parent_el}=${VARIABLE}

    Click Element    css:div[aria-describedby="${parent_el}"] > div + div + div > div > button


Press NO
    [Arguments]  ${parent_el}=${VARIABLE}

    Click Element    css:div[aria-describedby="${parent_el}"] > div > button


Delete Task
    Click Element    //div[@id="clone_delete_btn"]
    Sleep    1s
    Press OK    clone_delete_dialog


Delete Hash Task
    Click Element    //div[@id="hash_delete_btn"]
    Sleep    1s
    Press OK    hash_delete_dialog


Go to Exit
    Capture Page Screenshot
    [Teardown]    Close Browser


Assert Title
    [Arguments]  ${parent_el}=${VARIABLE}  ${parent_title}=${VARIABLE}

    Element Should Contain    css:div[aria-describedby="${parent_el}"] > div > span    ${parent_title}


Select Task Mode
    [Arguments]  ${mode}=${VARIABLE}

    Click Element    //div[@id="clone_mode_btn"]
    Assert Title    clone_mode_dialog    SELECT MODE
    Click Element    //div[@id="clone_mode_${mode}"]
    Press OK    clone_mode_dialog


Select Mode
    [Arguments]  ${mode}=${VARIABLE}

    Click Element    //div[@id="clone_mode_btn"]
    Assert Title    clone_mode_dialog    SELECT MODE
    Click Element    //div[@id="clone_mode_${dict_mode['${mode}']}"]
    Press OK    clone_mode_dialog


Select Source
    [Arguments]  ${src_id}=${VARIABLE}
    #${source_tname}=clone_master_select  ${source_dname}=clone_master_dialog
    Run Keyword If  ${two_param_f2f} == 1    Set Test Variable    ${source_tname}  clone_master_source_select
    Run Keyword If  ${two_param_f2f} == 1    Set Test Variable    ${source_dname}  clone_master_source_dialog

    Click Element    //div[@id="clone_master_btn_top"]
    Assert Title    ${source_dname}    SELECT SOURCE
    Table Cell Should Contain    //table[@id="${source_tname}"]    1    1    DRIVE PORT
    Sleep    1s
    Click Element    //td[contains(text(),"${src_id}")]
    Sleep    1s
    Press OK    ${source_dname}
    Run Keyword Unless  ${partition} == 0    Select Source Partition
    ${source}    Get Text    //div[@id="clone_master_btn_bottom"]
    Sleep    1s


Select Source Partition
    Assert Title    clone_master_partition_dialog    SELECT PARTITION
    Table Cell Should Contain    //table[@id="clone_master_partition_select"]    1    1    PARTITION
    Sleep    1s
    ${part_status_s1}    Get Table Cell    //table[@id="clone_master_partition_select"]    ${partition}    3
    ${part_name_s1}    Get Table Cell    //table[@id="clone_master_partition_select"]    ${partition}    1
    Click Element    //div[@id="clone_master_partition_dialog"]//tbody//tr[${partition}]//td[1]
    Sleep    1s
    ${drive_status_s2}    Get Table Cell    //table[@id="clone_master_partition_select"]    ${partition}    3
    Press OK    clone_master_partition_dialog
    # //*[@id="push_filesystem_select"]/tbody/tr[16]/td[2]
    # document.querySelector("#push_filesystem_select > tbody > tr.select_row.select-opt.ui-selected > td.col1")


Select Source Case
    [Arguments]  ${src_id}=${VARIABLE}  ${case_id}=${VARIABLE}

    Click Element    //div[@id="clone_master_btn_top"]
    Assert Title    push_filesystem_dialog    SELECT FILESYSTEM
    Table Cell Should Contain    //table[@id="push_filesystem_select"]    1    1    NAME
    PageDown Table And Click    ${src_id}
    Sleep    1s
    Press OK    push_filesystem_dialog

    Assert Title    push_case_dialog    SELECT CASE
    Table Cell Should Contain    //table[@id="push_case_select"]    1    1    CASE
    PageDown List And Click    ${case_id}
    Sleep    1s
    Press OK    push_case_dialog


PageDown Table And Click
    [Arguments]  ${cell_text}=${VARIABLE}

    #${loop_exit_el}    Get WebElement    xpath=//td[contains(text(),SAS_D2)]
    ${loop_exit_el}    Get WebElement    css:#push_filesystem_select > tbody > tr:nth-child(${cell_text}) > td.col1

    :FOR    ${i}    IN RANGE    9
    \    ${loop_exit_status}=  Run Keyword And Return Status  Element Should Be Visible    ${loop_exit_el}
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:#push_filesystem_dialog > #mcs_container47 > div > .mCSB_scrollTools >.mCSB_buttonDown
    \    Sleep    2s
    Click Element    ${loop_exit_el}


PageDown List And Click
    [Arguments]  ${source_text}=${VARIABLE}

    ${loop_exit_el}    Get WebElement    css:#push_case_select > tbody > tr:nth-child(${source_text}) > td.col1

    :FOR    ${i}    IN RANGE    9
    \    ${loop_exit_status}=  Run Keyword And Return Status  Element Should Be Visible    ${loop_exit_el}
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:#push_filesystem_dialog > #mcs_container41 > div > .mCSB_scrollTools >.mCSB_buttonDown
    \    Sleep    2s
    Click Element    ${loop_exit_el}


Change Length
    [Arguments]  ${num_blocks}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_method_block_content"]
    Assert Title    clone_mirror_dialog    MIRROR CLONE ADVANCED SETTINGS
    Click Element    //div[@id="clone_mirror_length_lbas"]
    Sleep    1s
    Set Focus To Element    //input[@id="blocks_val"]
    Clear Element Text    //input[@id="blocks_val"]
    Press Keys    //input[@id="blocks_val"]    ${num_blocks}
    Press OK    blocks_set_dialog
    Press OK    clone_mirror_dialog
    Press OK    clone_settings_dialog


Select Image Method Settings
    [Arguments]  ${image_type}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_file_image_block_content"]
    Assert Title    clone_file_image_dialog    FILE IMAGE METHOD SETTINGS
    Click Element    //div[@id="clone_capture_${dict_image['${image_type}']}"]
    Sleep    1s
    Press OK    clone_file_image_dialog
    Press OK    clone_settings_dialog


Select Segment Size
    [Arguments]  ${seg_size}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_file_image_block_content"]
    Assert Title    clone_file_image_dialog    FILE IMAGE METHOD SETTINGS

    Click Element    //div[@id="clone_segment_block_content"]
    Assert Title    clone_segment_dialog    SEGMENT SIZE
    Click Element    //div[@id="clone_segment_${dict_segment['${seg_size}']}"]
    Sleep    1s
    Press OK    clone_segment_dialog
    Press OK    clone_file_image_dialog
    Press OK    clone_settings_dialog


Select Output Segment Size
    [Arguments]  ${seg_size}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_output_format_block_content"]
    Assert Title    clone_output_format_dialog    OUTPUT FORMAT SETTINGS

    Click Element    //div[@id="clone_output_segment_block_content"]
    Assert Title    clone_segment_dialog    SEGMENT SIZE
    Click Element    //div[@id="clone_segment_${dict_segment['${seg_size}']}"]
    Sleep    1s
    Press OK    clone_segment_dialog
    Press OK    clone_output_format_dialog
    Press OK    clone_settings_dialog


Select Compression
    [Arguments]  ${compr}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_file_image_block_content"]
    Assert Title    clone_file_image_dialog    FILE IMAGE METHOD SETTINGS

    Click Element    //div[@id="clone_compression_block_content"]
    Assert Title    clone_compression_dialog    COMPRESSION
    Click Element    //div[@id="clone_dco_${dict_compr['${compr}']}"]
    Sleep    1s
    Press OK    clone_compression_dialog
    Press OK    clone_file_image_dialog
    Press OK    clone_settings_dialog


Select Output Compression
    [Arguments]  ${compr}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_output_format_block_content"]
    Assert Title    clone_output_format_dialog    OUTPUT FORMAT SETTINGS

    Click Element    //div[@id="clone_output_compression_block_content"]
    Assert Title    clone_compression_dialog    COMPRESSION
    Click Element    //div[@id="clone_dco_${dict_compr['${compr}']}"]
    Sleep    1s
    Press OK    clone_compression_dialog
    Press OK    clone_output_format_dialog
    Press OK    clone_settings_dialog


Select Hash Method
    [Arguments]  ${hash_method}=${VARIABLE}    ${verify}=0

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_verif_block_content"]
    Assert Title    clone_verif_dialog    HASH METHOD

    Click Element    //div[@id="clone_hash_${dict_hash['${hash_method}']}"]
    Sleep    1s
    Click Element    //div[@id="clone_verif_${dict_ver['${verify}']}"]
    Sleep    1s
    Press OK    clone_verif_dialog
    Press OK    clone_settings_dialog


Select Output Format
    [Arguments]  ${output_format}=${VARIABLE}

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_output_format_block_content"]
    Assert Title    clone_output_format_dialog    OUTPUT FORMAT SETTINGS
    Click Element    //div[@id="clone_output_format_${dict_output['${output_format}']}"]
    Sleep    1s
    Press OK    clone_output_format_dialog
    Press OK    clone_settings_dialog



Select Filter Settings
    [Arguments]  ${prtn}=${VARIABLE}  ${path_tree}=${VARIABLE}  ${path_filter}==NaN

    Click Element    //div[@id="clone_settings_btn_top"]
    Assert Title    clone_settings_dialog    SELECT SETTINGS
    Click Element    //div[@id="clone_filter_settings_block_content"]
    Assert Title    clone_filter_settings_dialog    ADVANCED FILTER SETTINGS
    Click Element    //div[@id="clone_path_filter_block"]
    Assert Title    clone_path_filter_dialog    SEARCH PATHS FILTER
    Click Element    //div[@id="clone_files_dirs_block"]
    Assert Title    clone_files_dirs_dialog    FILES / DIRECTORIES
    Click Element    //*[@id="${prtn}"]/i
    Sleep    1s
    @{words}=   Convert To List    ${path_tree}
    :FOR    ${element}    IN    @{words}
    \    Log    ${element}
    \    ${str_one}=    Catenate    SEPARATOR=/    ${str_one}    ${element}
    \    Sleep    1s
    \    PageDown Tree And Click    ${prtn}    ${str_one}
    \    Sleep    1s
    \    Click Element    //*[@id="${prtn}${str_one}"]/i
    Sleep    1s
    Click Element    //*[@id="${prtn}${str_one}_anchor"]

    Press OK    clone_files_dirs_dialog
    Press OK    clone_path_filter_dialog
    Press OK    clone_filter_settings_dialog
    Press OK    clone_settings_dialog

PageDown Tree And Click
    [Arguments]  ${prtn}=${VARIABLE}  ${path_target}=${VARIABLE}

    ${loopexitel}    Get WebElement    //*[@id="${prtn}${path_target}_anchor"]
    :FOR    ${i}    IN RANGE    9
    \    ${loopexitstatus}=  Run Keyword And Return Status  Element Should Be Visible    ${loopexitel}
    \    Exit For Loop If    ${loopexitstatus}
    \    Click Element    css:div[aria-describedby="clone_files_dirs_dialog"] > div + div > div > div > div + div > a.mCSB_buttonDown
    \    Sleep    2s

Select Drive Destination
    [Arguments]  ${trgt_id}=${VARIABLE}  ${dest_tname}=clone_target_select

    Click Element    //div[@id="clone_target_btn"]
    Assert Title    clone_target_dialog    SELECT DESTINATIONS
    Table Cell Should Contain    //table[@id="${dest_tname}"]    1    1    DRIVE PORT
    ${drive_param1}    Get Table Cell    //table[@id="${dest_tname}"]    ${trgt_id}    1
    Click Element    //*[@id="${dest_tname}"]/tbody/tr[${trgt_id}]/td[1]
    Press OK    clone_target_dialog
    ${target}    Get Text    //div[@id="clone_target_btn_bottom"]
    Capture Page Screenshot


Select File Destination
    [Arguments]  ${trgt_id}=${VARIABLE}  ${dest_tname}=clone_target_repo_select

    Click Element    //div[@id="clone_target_btn"]
    Assert Title    clone_target_repo_dialog    SELECT REPOSITORY
    Table Cell Should Contain    //table[@id="${dest_tname}"]    1    1    REPOSITORY
    Click Element    //div[contains(text(),"${trgt_id}")]
    Sleep    1s
    Press OK    clone_target_repo_dialog
    ${target}    Get Text    //div[@id="clone_target_btn_bottom"]
    Sleep    1s
    Capture Page Screenshot


Start Task
    ${start_btn}    Get WebElement    //div[@id="clone_start_btn"]
    Click Element    ${start_btn}
    Run Keyword Unless  ${norun_flag}==1    Press OK    clone_start_dialog
    Run Keyword If  ${norun_flag}==1    Press NO    clone_start_dialog
    Sleep    1s
    Run Keyword Unless  ${norun_flag}==1    Wait Until Element Contains    //div[@id="clone_progressbar_info"]     COMPLETED    12000000
    Sleep    1s


Delete All Hash Tasks
    Go to Hash
    Delete Hash Task
    Delete Hash Task
    Delete Hash Task
    Delete Hash Task
    Delete Hash Task


Result Should Contain Text
    Wait Until Page Contains    IMAGING    5 s


Open Browser For Empty Page
    [Arguments]
    Open Browser    about:blank
    Maximize Browser Window
